@@ -46,7 +46,7 @@ def unregister(func):
 
     func = function to be unregistered
     """
-    handler_entries = [e for e in _exithandlers if e[0] == self.stop]
+    handler_entries = [e for e in _exithandlers if e[0] == func]
     for e in handler_entries:
         _exithandlers.remove(e)
 
